@@ -19,16 +19,13 @@ async def async_main():
     # run concurrently.
 
     time_1 = aiocells.ModVariable(clock)
-    timer_1 = aiocells.source(functools.partial(aiocells.timer, 1, time_1))
-    assert aiocells.is_source(timer_1)
-
+    timer_1 = functools.partial(aiocells.timer, 1, time_1)
     printer_1 = aiocells.ModPrinter(clock, time_1, "time_1 changed to {value}")
     graph.add_precedence(timer_1, time_1)
     graph.add_precedence(time_1, printer_1)
 
     time_3 = aiocells.ModVariable(clock)
-    timer_3 = aiocells.source(functools.partial(aiocells.timer, 3, time_3))
-    assert aiocells.is_source(timer_3)
+    timer_3 = functools.partial(aiocells.timer, 3, time_3)
     printer_3 = aiocells.ModPrinter(clock, time_3, "time_3 changed to {value}")
     graph.add_precedence(timer_3, time_3)
     graph.add_precedence(time_3, printer_3)
